@@ -10,7 +10,7 @@ register = template.Library()
 @register.filter
 def hijackNotification(request):
     ans = ''
-    if getattr(settings, 'HIJACK_NOTIFY_ADMIN', True) and request.session.get('hijackedBySuperuser', False):
+    if getattr(settings, 'HIJACK_NOTIFY_ADMIN', True) and request.session.get('is_hijacked_user', False):
         ans = render_to_string('hijack/notifications.html', {}, context_instance=RequestContext(request)) 
     return mark_safe(ans) 
     
\ No newline at end of file
